#ifndef __TREEVIEW_H__


void create_root_element(GtkTreeView * treeview,  GtkTreeIter *iterator,
		int i,const gchar *home);


GtkTreeView *init_xffm_treeviews(int argc, char *argv[]);
#endif
